==> php83-nextcloud-30.0.2.tgz: share/nextcloud/apps/systemtags/l10n/cs.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systémový štítek %1$s přidán systémem",
    "Added system tag {systemtag}" : "Přidán systémový štítek {systemtag}",
    "Added system tag %1$s" : "Přidán systémový štítek %1$s",
    "%1$s added system tag %2$s" : "%1$s přidal(a) systémový štítek %2$s",
    "{actor} added system tag {systemtag}" : "{actor} přidal(a) systémový štítek {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítek %1$s odebrán systémem",
    "Removed system tag {systemtag}" : "Odebrán systémový štítek {systemtag}",
    "Removed system tag %1$s" : "Odebrán systémový štítek %1$s",
    "%1$s removed system tag %2$s" : "%1$s odebral(a) systémový štítek %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odebral(a) systémový štítek {systemtag}",
    "You created system tag %1$s" : "Vytvořili jste systémový štítek %1$s",
    "You created system tag {systemtag}" : "Vytvořili jste systémový štítek {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvořil(a) systémový štítek %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvořil(a) systémový štítek {systemtag}",
    "You deleted system tag %1$s" : "Smazali jste systémový štítek %1$s",
    "You deleted system tag {systemtag}" : "Smazali jste systémový štítek {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s smazal(a) systémový štítek %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} smazal(a) systémový štítek {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali jste systémový štítek %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali jste systémový štítek {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítek %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítek {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítek %2$s byl přidán k %1$s systémem",
    "System tag {systemtag} was added to {file} by the system" : "Systémový štítek {systemtag} byl přidán k {file} systémem",
    "You added system tag %2$s to %1$s" : "Přidali jste systémový štítek %2$s k %1$s",
    "You added system tag {systemtag} to {file}" : "Přidali jste systémový štítek {systemtag} k {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s přidal(a) systémový štítek %3$s k %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} přidal(a) systémový štítek {systemtag} k {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systémový štítek %2$s byl odebrán z %1$s systémem",
    "System tag {systemtag} was removed from {file} by the system" : "Systémový štítek {systemtag} byl odebrán z {file} systémem",
    "You removed system tag %2$s from %1$s" : "Z %2$s jste odebrali systémový štítek %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} jste odebrali systémový štítek {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odebral(a) systémový štítek %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odebral(a) systémový štítek {systemtag} z {file}",
    "%s (restricted)" : "%s (uživatelsky nepřiřaditelné)",
    "%s (invisible)" : "%s (neviditelný)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> souboru byly upraveny",
    "Files" : "Soubory",
    "Tags" : "Štítky",
    "All tagged %s …" : "Vše oštítkované %s …",
    "tagged %s" : "oštítkované %s",
    "Collaborative tags" : "Štítky pro spolupráci",
    "Collaborative tagging functionality which shares tags among people." : "Funkce opatřování štítky pro spolupráci, sdílenými mezi lidmi.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkce pro opatřování štítky pro spolupráci, sdílenými mezi lidmi. Skvělé pro týmy.\n\t(Pokud jste poskytovateli instalace, sloužící více subjektům, je doporučeno tuto aplikaci vypnout, protože štítky jsou sdílené.)",
    "Create or edit tags" : "Vytvořit nebo upravit štítky",
    "Search for a tag to edit" : "Vyhledat štítek pro úpravu",
    "Collaborative tags …" : "Štítky pro spolupráci…",
    "No tags to select" : "Žádné štítky k výběru",
    "Tag name" : "Název štítku",
    "Tag level" : "Úroveň štítku",
    "Create" : "Vytvořit",
    "Update" : "Aktualizovat",
    "Delete" : "Smazat",
    "Reset" : "Vrátit na výchozí",
    "Loading …" : "Načítání…",
    "Public" : "Veřejný",
    "Restricted" : "Uživatelsky nepřiřaditelný",
    "Invisible" : "Neviditelný",
    "Created tag" : "Vytvořen štítek",
    "Failed to create tag" : "Štítek se nepodařilo vytvořit",
    "Updated tag" : "Zaktualizován štítek",
    "Failed to update tag" : "Nepodařilo se zaktualizovat štítek",
    "Deleted tag" : "Smazán štítek",
    "Failed to delete tag" : "Štítek se nepodařilo smazat",
    "Manage tags" : "Spravovat štítky",
    "No tags found" : "Nenalezeny žádné štítky",
    "Cancel" : "Storno",
    "Loading collaborative tags …" : "Načítání štítků pro spolupráci…",
    "Search or create collaborative tags" : "Hledat nebo vytvořit štítky pro spolupráci",
    "No tags to select, type to create a new tag" : "Nevybrány žádné štítky k výběru – psaním vytvořte nový",
    "Failed to load tags" : "Štítky se nepodařilo načíst",
    "Failed to load selected tags" : "Vybrané štítky se nepodařilo načíst",
    "Failed to select tag" : "Štítek se nepodařilo načíst",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pro spolupráci jsou k dispozici všem uživatelům. Uživatelsky nepřiřaditelné štítky jsou uživatelům viditelné, ale nemohou je přiřazovat.\nNeviditelné štítky jsou pro vnitřní potřebu, protože uživatelé je nemohou vidět ani je přiřazovat.",
    "Assigned collaborative tags" : "Přiřazené štítky pro spolupráci",
    "Open in Files" : "Otevřít v Souborech",
    "List of tags and their associated files and folders." : "Seznam štítků a jejich souvisejících souborů a složek.",
    "Tags you have created will show up here." : "Štítky které jste vytvořili se zobrazí zde.",
    "Failed to load last used tags" : "Nepodařilo se načíst nedávno použité štítky",
    "Missing \"Content-Location\" header" : "Chybí hlavička „Content-Location“",
    "Failed to load tags for file" : "Nepodařilo se načíst štítky pro soubor",
    "Failed to set tag for file" : "Nepodařilo se nastavit štítek pro soubor",
    "Failed to delete tag for file" : "Nepodařilo se smazat štítek pro soubor",
    "Collaborative tagging functionality which shares tags among users." : "Funkce opatřování štítky pro spolupráci, sdílenými mezi uživateli.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkce pro opatřování štítky pro spolupráci, sdílenými mezi uživateli. Skvělé pro týmy.\n\t(Pokud jste poskytovateli instalace, sloužící více subjektům, je doporučeno tuto aplikaci vypnout, protože štítky jsou sdílené.)",
    "This file has the tag {tag}" : "Tento soubor má štítek {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tento soubor má štítky {firstTags} a {lastTag}",
    "No files in here" : "Nejsou zde žádné soubory",
    "No entries found in this folder" : "V této složce nic nenalezeno",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Změněno"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> php83-nextcloud-30.0.15.tgz: share/nextcloud/apps/systemtags/l10n/cs.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systémový štítek %1$s přidán systémem",
    "Added system tag {systemtag}" : "Přidán systémový štítek {systemtag}",
    "Added system tag %1$s" : "Přidán systémový štítek %1$s",
    "%1$s added system tag %2$s" : "%1$s přidal(a) systémový štítek %2$s",
    "{actor} added system tag {systemtag}" : "{actor} přidal(a) systémový štítek {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítek %1$s odebrán systémem",
    "Removed system tag {systemtag}" : "Odebrán systémový štítek {systemtag}",
    "Removed system tag %1$s" : "Odebrán systémový štítek %1$s",
    "%1$s removed system tag %2$s" : "%1$s odebral(a) systémový štítek %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odebral(a) systémový štítek {systemtag}",
    "You created system tag %1$s" : "Vytvořili jste systémový štítek %1$s",
    "You created system tag {systemtag}" : "Vytvořili jste systémový štítek {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvořil(a) systémový štítek %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvořil(a) systémový štítek {systemtag}",
    "You deleted system tag %1$s" : "Smazali jste systémový štítek %1$s",
    "You deleted system tag {systemtag}" : "Smazali jste systémový štítek {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s smazal(a) systémový štítek %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} smazal(a) systémový štítek {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali jste systémový štítek %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali jste systémový štítek {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítek %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítek {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítek %2$s byl přidán k %1$s systémem",
    "System tag {systemtag} was added to {file} by the system" : "Systémový štítek {systemtag} byl přidán k {file} systémem",
    "You added system tag %2$s to %1$s" : "Přidali jste systémový štítek %2$s k %1$s",
    "You added system tag {systemtag} to {file}" : "Přidali jste systémový štítek {systemtag} k {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s přidal(a) systémový štítek %3$s k %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} přidal(a) systémový štítek {systemtag} k {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systémový štítek %2$s byl odebrán z %1$s systémem",
    "System tag {systemtag} was removed from {file} by the system" : "Systémový štítek {systemtag} byl odebrán z {file} systémem",
    "You removed system tag %2$s from %1$s" : "Z %2$s jste odebrali systémový štítek %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} jste odebrali systémový štítek {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odebral(a) systémový štítek %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odebral(a) systémový štítek {systemtag} z {file}",
    "%s (restricted)" : "%s (uživatelsky nepřiřaditelné)",
    "%s (invisible)" : "%s (neviditelný)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> souboru byly upraveny",
    "Files" : "Soubory",
    "Tags" : "Štítky",
    "All tagged %s …" : "Vše oštítkované %s …",
    "tagged %s" : "oštítkované %s",
    "Collaborative tags" : "Štítky pro spolupráci",
    "Collaborative tagging functionality which shares tags among people." : "Funkce opatřování štítky pro spolupráci, sdílenými mezi lidmi.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkce pro opatřování štítky pro spolupráci, sdílenými mezi lidmi. Skvělé pro týmy.\n\t(Pokud jste poskytovateli instalace, sloužící více subjektům, je doporučeno tuto aplikaci vypnout, protože štítky jsou sdílené.)",
    "Public" : "Veřejný",
    "Restricted" : "Uživatelsky nepřiřaditelný",
    "Invisible" : "Neviditelný",
    "Created tag" : "Vytvořen štítek",
    "Failed to create tag" : "Štítek se nepodařilo vytvořit",
    "Updated tag" : "Zaktualizován štítek",
    "Failed to update tag" : "Nepodařilo se zaktualizovat štítek",
    "Deleted tag" : "Smazán štítek",
    "Failed to delete tag" : "Štítek se nepodařilo smazat",
    "Create or edit tags" : "Vytvořit nebo upravit štítky",
    "Search for a tag to edit" : "Vyhledat štítek pro úpravu",
    "Collaborative tags …" : "Štítky pro spolupráci…",
    "No tags to select" : "Žádné štítky k výběru",
    "Tag name" : "Název štítku",
    "Tag level" : "Úroveň štítku",
    "Create" : "Vytvořit",
    "Update" : "Aktualizovat",
    "Delete" : "Smazat",
    "Reset" : "Vrátit na výchozí",
    "Loading …" : "Načítání…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} bude nastaven a {tag2} odebrán z 1 souboru.","{tag1} bude nastaven a {tag2} odebrán z {count} souborů.","{tag1} bude nastaven a {tag2} odebrán z {count} souborů.","{tag1} bude nastaven a {tag2} odebrán z {count} souborů."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} bude nastaven 1 souboru.","{tag} bude nastaven {count} souborům.","{tag} bude nastaven {count} souborům.","{tag} bude nastaven {count} souborům."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} bude odebrán z 1 souboru.","{tag} bude odebrán z {count} souborů.","{tag} bude odebrán z {count} souborů.","{tag} bude odebrán z {count} souborů."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} a {lastTag} bude nastaven 1 souboru.","{tags} a {lastTag} bude nastaven {count} souborům.","{tags} a {lastTag} bude nastaven {count} souborům.","{tags} a {lastTag} bude nastaven {count} souborům."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} a {lastTag} bude odebrán 1 souboru.","{tags} a {lastTag} bude odebrán {count} souborům.","{tags} a {lastTag} bude odebrán {count} souborům.","{tags} a {lastTag} bude odebrán {count} souborům."],
    "{displayName} (hidden)" : "{displayName} (skrytý)",
    "{displayName} (restricted)" : "{displayName} (omezený)",
    "Only admins can create new tags" : "Nové štítky mohou vytvářet pouze správci",
    "Failed to apply tags changes" : "Změny štítků se nepodařilo uplatnit",
    "Manage tags" : "Spravovat štítky",
    "Applying tags changes…" : "Uplatňování směn štítků…",
    "Search or create tag" : "Hledat nebo vytvořit štítek",
    "Search tag" : "Hledat štítek",
    "Change tag color" : "Změnit barvu štítku",
    "Create new tag" : "Vytvořit nový  štítek",
    "Cancel" : "Storno",
    "Apply" : "Použít",
    "Failed to load tags" : "Štítky se nepodařilo načíst",
    "Failed to load selected tags" : "Vybrané štítky se nepodařilo načíst",
    "Failed to select tag" : "Štítek se nepodařilo načíst",
    "System admin disabled tag creation. You can only use existing ones." : "Správce systému zakázal vytváření štítků. Je možné pouze používat ty stávající.",
    "Loading collaborative tags …" : "Načítání štítků pro spolupráci…",
    "Search or create collaborative tags" : "Hledat nebo vytvořit štítky pro spolupráci",
    "No tags to select, type to create a new tag" : "Nevybrány žádné štítky k výběru – psaním vytvořte nový",
    "Unable to update setting" : "Nedaří se nahrát nastavení",
    "System tag creation is now restricted to administrators" : "Systémové štítky nyní mohou vytvářet pouze správci",
    "System tag creation is now allowed for everybody" : "Systémové štítky nyní může vytvářet kdokoli",
    "System tag management" : "Správa systémových štítků",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Pokud zapnuto, vytvářet a upravovat štítky budou moci pouze správci. Uživatelé je i tak mohou přiřazovat a odebírat je souborům.",
    "Restrict tag creation and editing to administrators" : "Omezit vytváření a upravování štítků pouze na správce",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pro spolupráci jsou k dispozici všem uživatelům. Uživatelsky nepřiřaditelné štítky jsou uživatelům viditelné, ale nemohou je přiřazovat.\nNeviditelné štítky jsou pro vnitřní potřebu, protože uživatelé je nemohou vidět ani je přiřazovat.",
    "Assigned collaborative tags" : "Přiřazené štítky pro spolupráci",
    "Open in Files" : "Otevřít v Souborech",
    "List of tags and their associated files and folders." : "Seznam štítků a jejich souvisejících souborů a složek.",
    "No tags found" : "Nenalezeny žádné štítky",
    "Tags you have created will show up here." : "Štítky které jste vytvořili se zobrazí zde.",
    "Failed to load tag" : "Štítek se nepodařilo načíst",
    "Failed to load last used tags" : "Nepodařilo se načíst nedávno použité štítky",
    "Missing \"Content-Location\" header" : "Chybí hlavička „Content-Location“",
    "A tag with the same name already exists" : "Takto znazvaný štítek už existuje",
    "Failed to load tags for file" : "Nepodařilo se načíst štítky pro soubor",
    "Failed to set tag for file" : "Nepodařilo se nastavit štítek pro soubor",
    "Failed to delete tag for file" : "Nepodařilo se smazat štítek pro soubor",
    "File tags modification canceled" : "Změna štítků souboru zrušena",
    "Select or create tags to apply to all selected files" : "Vyberte nebo vytvořte štítky které uplatnit ne všechny označené soubory",
    "Select tags to apply to all selected files" : "Vybrat štítky které uplatnit na všechny vybrané soubory",
    "Apply changes" : "Uplatnit změny"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
